##  Monitor Progress Using Metrics
To monitor progress, use the following metrics on the onboarding dashboard for enterprise architects. For additional information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
Metrics for Applications Metric | Explanation
---|---
Applications* are added to the workspace, using at least 60% of the quota. | An important prerequisite for effective enterprise architecture governance is creating transparency in your entire application portfolio. We encourage importing all known applications into the workspace, aiming for at least 60% of your quota to start. To reflect the focus of your current architecture work, use the "In scope" field for a focused subset of your landscape. See the following metric for more details.
At least 20 applications* are in scope. | When you're getting onboarded to SAP LeanIX, start with at least 20 critical applications. After assessing the initial set of applications, extend the scope.
At least 20 applications* have a description. | Application descriptions help stakeholders understand their purpose. Names alone may not be universally understood. To streamline the process of creating descriptions, you can use AI capabilities, available in the upper-right corner of the inventory. For more information, see [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "AI capabilities in SAP LeanIX automate documentation tasks, offer contextual insights, and support natural language queries to streamline enterprise architecture management. Use it to boost efficiency, reduce manual work, and maintain compliance with data privacy and ethical standards.").


*Count all application fact sheets where the subtype is business application or empty.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
